@@ -1,9 +1,8 @@
-use 5.008003;
-use YamlTime 0.10 ();
-
+use strict; use warnings;
 package YamlTime::Git;
+our $VERSION = '0.07';
 
-our $VERSION = '0.06';
+use YamlTime 0.10 ();
 
 # XXX Put this here on 28/07/2011. Leave in for a while...
 {
